@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-07-21'; # DATE
+our $DATE = '2023-07-25'; # DATE
 our $DIST = 'App-CSVUtils'; # DIST
-our $VERSION = '1.029'; # VERSION
+our $VERSION = '1.030'; # VERSION
 
 use App::CSVUtils qw(
                         gen_csv_util
@@ -45,7 +45,7 @@ _
     add_args => {
         %App::CSVUtils::argspecopt_with_data_rows,
     },
-    tags => ['add-row','category:summarizing'],
+    tags => ['adds-row','category:summarizing'],
 
     on_input_header_row => sub {
         my $r = shift;
@@ -97,7 +97,7 @@ App::CSVUtils::csv_avg - Output a summary row which are arithmetic averages of d
 
 =head1 VERSION
 
-This document describes version 1.029 of App::CSVUtils::csv_avg (from Perl distribution App-CSVUtils), released on 2023-07-21.
+This document describes version 1.030 of App::CSVUtils::csv_avg (from Perl distribution App-CSVUtils), released on 2023-07-25.
 
 =head1 FUNCTIONS
 
