@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-07-21'; # DATE
+our $DATE = '2023-07-25'; # DATE
 our $DIST = 'App-CSVUtils'; # DIST
-our $VERSION = '1.029'; # VERSION
+our $VERSION = '1.030'; # VERSION
 
 use App::CSVUtils qw(
                         gen_csv_util
@@ -46,7 +46,7 @@ _
         %App::CSVUtils::argspecopt_with_data_rows,
     },
 
-    tags => ['category:summarizing'],
+    tags => ['category:summarizing', 'adds-field'],
 
     on_input_header_row => sub {
         my $r = shift;
@@ -93,7 +93,7 @@ App::CSVUtils::csv_sum - Output a summary row which are arithmetic sum of data r
 
 =head1 VERSION
 
-This document describes version 1.029 of App::CSVUtils::csv_sum (from Perl distribution App-CSVUtils), released on 2023-07-21.
+This document describes version 1.030 of App::CSVUtils::csv_sum (from Perl distribution App-CSVUtils), released on 2023-07-25.
 
 =head1 FUNCTIONS
 
